@@ -3,12 +3,11 @@ from unittest.mock import call
 
 import pytest
 
+from zwave_js_server.const import __version__
 from zwave_js_server.dump import dump_msgs
 
 from .common import update_ws_client_msg_queue
 
-# pylint: disable=too-many-arguments
-
 
 @pytest.fixture(name="event")
 def event_fixture():
@@ -37,23 +36,23 @@ async def test_dump(
     result,
     url,
     version_data,
-    set_api_schema_data,
+    initialize_data,
     ws_client,
 ):
     """Test the dump function."""
-    update_ws_client_msg_queue(ws_client, (version_data, set_api_schema_data, result))
+    update_ws_client_msg_queue(ws_client, (version_data, initialize_data, result))
     messages = await dump_msgs(url, client_session)
 
     assert ws_client.receive_json.call_count == 3
     assert ws_client.send_json.call_count == 2
     assert ws_client.send_json.call_args == call(
-        {"command": "start_listening", "messageId": "listen-id"}
+        {"command": "start_listening", "messageId": "start-listening"}
     )
     assert ws_client.close.call_count == 1
     assert messages
     assert len(messages) == 3
     assert messages[0] == version_data
-    assert messages[1] == set_api_schema_data
+    assert messages[1] == initialize_data
     assert messages[2] == result
 
 
@@ -63,24 +62,59 @@ async def test_dump_timeout(
     url,
     event,
     version_data,
-    set_api_schema_data,
+    initialize_data,
     ws_client,
 ):
     """Test the dump function with timeout."""
     update_ws_client_msg_queue(
-        ws_client, (version_data, set_api_schema_data, result, event)
+        ws_client, (version_data, initialize_data, result, event)
     )
-    messages = await dump_msgs(url, client_session, 0.05)
+    messages = await dump_msgs(url, client_session, timeout=0.05)
 
     assert ws_client.receive_json.call_count == 5
     assert ws_client.send_json.call_count == 2
     assert ws_client.send_json.call_args == call(
-        {"command": "start_listening", "messageId": "listen-id"}
+        {"command": "start_listening", "messageId": "start-listening"}
     )
     assert ws_client.close.call_count == 1
     assert messages
     assert len(messages) == 4
     assert messages[0] == version_data
-    assert messages[1] == set_api_schema_data
+    assert messages[1] == initialize_data
     assert messages[2] == result
     assert messages[3] == event
+
+
+async def test_dump_additional_user_agent_components(
+    client_session,
+    result,
+    url,
+    version_data,
+    initialize_data,
+    ws_client,
+):
+    """Test the dump function with additional user agent components."""
+    update_ws_client_msg_queue(ws_client, (version_data, initialize_data, result))
+    messages = await dump_msgs(
+        url, client_session, additional_user_agent_components={"foo": "bar"}
+    )
+
+    assert ws_client.receive_json.call_count == 3
+    assert ws_client.send_json.call_count == 2
+    assert ws_client.send_json.call_args_list[0] == call(
+        {
+            "command": "initialize",
+            "messageId": "initialize",
+            "schemaVersion": 23,
+            "additionalUserAgentComponents": {
+                "zwave-js-server-python": __version__,
+                "foo": "bar",
+            },
+        }
+    )
+    assert ws_client.close.call_count == 1
+    assert messages
+    assert len(messages) == 3
+    assert messages[0] == version_data
+    assert messages[1] == initialize_data
+    assert messages[2] == result
