@@ -12,7 +12,12 @@ from typing import Any, DefaultDict, Dict, List, Optional, cast
 
 from aiohttp import ClientSession, ClientWebSocketResponse, WSMsgType, client_exceptions
 
-from .const import MAX_SERVER_SCHEMA_VERSION, MIN_SERVER_SCHEMA_VERSION
+from .const import (
+    MAX_SERVER_SCHEMA_VERSION,
+    MIN_SERVER_SCHEMA_VERSION,
+    PACKAGE_NAME,
+    __version__,
+)
 from .event import Event
 from .exceptions import (
     CannotConnect,
@@ -31,13 +36,13 @@ from .model.version import VersionInfo, VersionInfoDataType
 SIZE_PARSE_JSON_EXECUTOR = 8192
 
 # Message IDs
-SET_API_SCHEMA_MESSAGE_ID = "api-schema-id"
+INITIALIZE_MESSAGE_ID = "initialize"
 GET_INITIAL_LOG_CONFIG_MESSAGE_ID = "get-initial-log-config"
-START_LISTENING_MESSAGE_ID = "listen-id"
+START_LISTENING_MESSAGE_ID = "start-listening"
 
 LISTEN_MESSAGE_IDS = (
     GET_INITIAL_LOG_CONFIG_MESSAGE_ID,
-    SET_API_SCHEMA_MESSAGE_ID,
+    INITIALIZE_MESSAGE_ID,
     START_LISTENING_MESSAGE_ID,
 )
 
@@ -50,6 +55,7 @@ class Client:
         ws_server_url: str,
         aiohttp_session: ClientSession,
         schema_version: int = MAX_SERVER_SCHEMA_VERSION,
+        additional_user_agent_components: Optional[Dict[str, str]] = None,
         record_messages: bool = False,
     ):
         """Initialize the Client class."""
@@ -61,6 +67,10 @@ class Client:
         # Version of the connected server
         self.version: Optional[VersionInfo] = None
         self.schema_version: int = schema_version
+        self.additional_user_agent_components = {
+            PACKAGE_NAME: __version__,
+            **(additional_user_agent_components or {}),
+        }
         self._logger = logging.getLogger(__package__)
         self._loop = asyncio.get_running_loop()
         self._result_futures: Dict[str, asyncio.Future] = {}
@@ -91,9 +101,12 @@ class Client:
     ) -> dict:
         """Send a command and get a response."""
         if require_schema is not None and require_schema > self.schema_version:
+            assert self.version
             raise InvalidServerVersion(
+                self.version,
+                require_schema,
                 "Command not available due to incompatible server version. Update the Z-Wave "
-                f"JS Server to a version that supports at least api schema {require_schema}."
+                f"JS Server to a version that supports at least api schema {require_schema}.",
             )
         future: "asyncio.Future[dict]" = self._loop.create_future()
         message_id = message["messageId"] = uuid.uuid4().hex
@@ -109,9 +122,12 @@ class Client:
     ) -> None:
         """Send a command without waiting for the response."""
         if require_schema is not None and require_schema > self.schema_version:
+            assert self.version
             raise InvalidServerVersion(
+                self.version,
+                require_schema,
                 "Command not available due to incompatible server version. Update the Z-Wave "
-                f"JS Server to a version that supports at least api schema {require_schema}."
+                f"JS Server to a version that supports at least api schema {require_schema}.",
             )
         message["messageId"] = uuid.uuid4().hex
         await self._send_json_message(message)
@@ -145,10 +161,13 @@ class Client:
             or self.version.max_schema_version < MIN_SERVER_SCHEMA_VERSION
         ):
             await self._client.close()
+            assert self.version
             raise InvalidServerVersion(
-                f"Z-Wave JS Server version is incompatible: {self.version.server_version} "
-                "a version is required that supports at least "
-                f"api schema {MIN_SERVER_SCHEMA_VERSION}"
+                self.version,
+                MIN_SERVER_SCHEMA_VERSION,
+                f"Z-Wave JS Server version ({self.version.server_version}) is "
+                "incompatible. Update the Z-Wave JS Server to a version that supports "
+                f"at least api schema {MIN_SERVER_SCHEMA_VERSION}",
             )
         # store the (highest possible) schema version we're going to use/request
         # this is a bit future proof as we might decide to use a pinned version at some point
@@ -165,17 +184,18 @@ class Client:
             self.schema_version,
         )
 
-    async def set_api_schema(self) -> None:
-        """Set API schema version on server."""
+    async def initialize(self) -> None:
+        """Initialize connection to server by setting schema version and user agent."""
         assert self._client
 
         # set preferred schema version on the server
         # note: we already check for (in)compatible schemas in the connect call
         await self._send_json_message(
             {
-                "command": "set_api_schema",
-                "messageId": SET_API_SCHEMA_MESSAGE_ID,
+                "command": "initialize",
+                "messageId": INITIALIZE_MESSAGE_ID,
                 "schemaVersion": self.schema_version,
+                "additionalUserAgentComponents": self.additional_user_agent_components,
             }
         )
         set_api_msg = await self._receive_json_or_raise()
@@ -193,7 +213,7 @@ class Client:
         assert self._client
 
         try:
-            await self.set_api_schema()
+            await self.initialize()
 
             await self._send_json_message(
                 {
@@ -238,10 +258,7 @@ class Client:
                 "Z-Wave JS initialized. %s nodes", len(self.driver.controller.nodes)
             )
 
-            while not self._client.closed:
-                data = await self._receive_json_or_raise()
-
-                self._handle_incoming_message(data)
+            await self.receive_until_closed()
         except ConnectionClosed:
             pass
 
@@ -302,6 +319,15 @@ class Client:
 
         return list(data)
 
+    async def receive_until_closed(self) -> None:
+        """Receive messages until client is closed."""
+        assert self._client
+
+        while not self._client.closed:
+            data = await self._receive_json_or_raise()
+
+            self._handle_incoming_message(data)
+
     async def _receive_json_or_raise(self) -> dict:
         """Receive json or raise."""
         assert self._client
