@@ -1,11 +1,15 @@
 """Constants for the Z-Wave JS python library."""
 import sys
 from enum import Enum, IntEnum
+from importlib import metadata
+
+PACKAGE_NAME = "zwave-js-server-python"
+__version__ = metadata.version(PACKAGE_NAME)
 
 # minimal server schema version we can handle
-MIN_SERVER_SCHEMA_VERSION = 22
+MIN_SERVER_SCHEMA_VERSION = 23
 # max server schema version we can handle (and our code is compatible with)
-MAX_SERVER_SCHEMA_VERSION = 22
+MAX_SERVER_SCHEMA_VERSION = 23
 
 TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED = sys.version_info < (3, 9, 2)
 
