@@ -1,5 +1,6 @@
 """Firmware update helper."""
-from typing import Optional
+import asyncio
+from typing import Dict, Optional
 
 import aiohttp
 
@@ -14,12 +15,18 @@ async def begin_firmware_update(
     filename: str,
     file: bytes,
     session: aiohttp.ClientSession,
+    additional_user_agent_components: Optional[Dict[str, str]] = None,
     file_format: Optional[str] = None,
+    target: Optional[int] = None,
 ) -> None:
     """Send beginFirmwareUpdate command to Node."""
-    client = Client(url, session)
+    client = Client(
+        url, session, additional_user_agent_components=additional_user_agent_components
+    )
     await client.connect()
-    await client.set_api_schema()
+    await client.initialize()
+
+    receive_task = asyncio.get_running_loop().create_task(client.receive_until_closed())
 
     cmd = {
         "command": "node.begin_firmware_update",
@@ -30,5 +37,10 @@ async def begin_firmware_update(
     if file_format is not None:
         cmd["firmwareFileFormat"] = file_format
 
-    await client.async_send_command(cmd, require_schema=5)
+    if target is not None:
+        cmd["target"] = target
+
+    await client.async_send_command(cmd, require_schema=18)
     await client.disconnect()
+    if not receive_task.done():
+        receive_task.cancel()
