@@ -32,12 +32,12 @@ from ..firmware import (
 from ..notification import (
     EntryControlNotification,
     EntryControlNotificationDataType,
+    MultilevelSwitchNotification,
+    MultilevelSwitchNotificationDataType,
     NotificationNotification,
     NotificationNotificationDataType,
     PowerLevelNotification,
     PowerLevelNotificationDataType,
-    MultilevelSwitchNotification,
-    MultilevelSwitchNotificationDataType,
 )
 from ..value import (
     ConfigurationValue,
@@ -46,7 +46,7 @@ from ..value import (
     ValueDataType,
     ValueMetadata,
     ValueNotification,
-    _get_value_id_from_dict,
+    _get_value_id_str_from_dict,
     _init_value,
 )
 from .data_model import NodeDataType
@@ -66,6 +66,21 @@ if TYPE_CHECKING:
 _LOGGER = logging.getLogger(__package__)
 
 
+def _get_value_id_dict_from_value_data(value_data: ValueDataType) -> Dict[str, Any]:
+    """Return a value ID dict from ValueDataType."""
+    data = {
+        "commandClass": value_data["commandClass"],
+        "property": value_data["property"],
+    }
+
+    if (endpoint := value_data.get("endpoint")) is not None:
+        data["endpoint"] = endpoint
+    if (property_key := value_data.get("propertyKey")) is not None:
+        data["propertyKey"] = property_key
+
+    return data
+
+
 class Node(EventBase):
     """Represent a Z-Wave JS node."""
 
@@ -322,7 +337,7 @@ class Node(EventBase):
         self._statistics = NodeStatistics(self.client, self.data.get("statistics"))
 
         # Remove stale values
-        value_ids = (_get_value_id_from_dict(self, val) for val in data["values"])
+        value_ids = (_get_value_id_str_from_dict(self, val) for val in data["values"])
         self.values = {
             value_id: val
             for value_id, val in self.values.items()
@@ -332,7 +347,7 @@ class Node(EventBase):
         # Populate new values
         for val in data["values"]:
             try:
-                if (value_id := _get_value_id_from_dict(self, val)) in self.values:
+                if (value_id := _get_value_id_str_from_dict(self, val)) in self.values:
                     self.values[value_id].update(val)
                 else:
                     self.values[value_id] = _init_value(self, val)
@@ -436,7 +451,7 @@ class Node(EventBase):
             raise UnwriteableValue
 
         cmd_args = {
-            "valueId": val.data,
+            "valueId": _get_value_id_dict_from_value_data(val.data),
             "value": new_value,
         }
         if options:
@@ -504,7 +519,9 @@ class Node(EventBase):
             val = self.values[val]
         # the value object needs to be send to the server
         data = await self.async_send_command(
-            "get_value_metadata", valueId=val.data, wait_for_result=True
+            "get_value_metadata",
+            valueId=_get_value_id_dict_from_value_data(val.data),
+            wait_for_result=True,
         )
         return ValueMetadata(cast(MetaDataType, data))
 
@@ -545,7 +562,11 @@ class Node(EventBase):
         # a value may be specified as value_id or the value itself
         if not isinstance(val, Value):
             val = self.values[val]
-        await self.async_send_command("poll_value", valueId=val.data, require_schema=1)
+        await self.async_send_command(
+            "poll_value",
+            valueId=_get_value_id_dict_from_value_data(val.data),
+            require_schema=1,
+        )
 
     async def async_ping(self) -> bool:
         """Send ping command to Node."""
@@ -573,6 +594,26 @@ class Node(EventBase):
         """Call endpoint.supports_cc_api command."""
         return await self.endpoints[0].async_supports_cc_api(command_class)
 
+    async def async_supports_cc(self, command_class: CommandClass) -> bool:
+        """Call endpoint.supports_cc command."""
+        return await self.endpoints[0].async_supports_cc(command_class)
+
+    async def async_controls_cc(self, command_class: CommandClass) -> bool:
+        """Call endpoint.controls_cc command."""
+        return await self.endpoints[0].async_controls_cc(command_class)
+
+    async def async_is_cc_secure(self, command_class: CommandClass) -> bool:
+        """Call endpoint.is_cc_secure command."""
+        return await self.endpoints[0].async_is_cc_secure(command_class)
+
+    async def async_get_cc_version(self, command_class: CommandClass) -> bool:
+        """Call endpoint.get_cc_version command."""
+        return await self.endpoints[0].async_get_cc_version(command_class)
+
+    async def async_get_node_unsafe(self) -> NodeDataType:
+        """Call endpoint.get_node_unsafe command."""
+        return await self.endpoints[0].async_get_node_unsafe()
+
     async def async_has_security_class(self, security_class: SecurityClass) -> bool:
         """Return whether node has the given security class."""
         data = await self.async_send_command(
@@ -639,13 +680,13 @@ class Node(EventBase):
         assert data
         return RouteHealthCheckSummary(data["summary"])
 
-    async def async_get_state(self) -> None:
+    async def async_get_state(self) -> NodeDataType:
         """Get node state."""
         data = await self.async_send_command(
             "get_state", require_schema=14, wait_for_result=True
         )
         assert data
-        self.update(data["state"])
+        return cast(NodeDataType, data["state"])
 
     async def async_set_name(
         self, name: str, update_cc: bool = True, wait_for_result: Optional[bool] = None
@@ -706,6 +747,14 @@ class Node(EventBase):
         )
         self.data["keepAwake"] = keep_awake
 
+    async def async_interview(self) -> None:
+        """Interview node."""
+        await self.async_send_command(
+            "interview",
+            wait_for_result=False,
+            require_schema=22,
+        )
+
     def handle_test_powerlevel_progress(self, event: Event) -> None:
         """Process a test power level progress event."""
         event.data["test_power_level_progress"] = TestPowerLevelProgress(
@@ -779,13 +828,13 @@ class Node(EventBase):
         return next(
             idx
             for idx in range(len(values))
-            if _get_value_id_from_dict(self, values[idx]) == value_id
+            if _get_value_id_str_from_dict(self, values[idx]) == value_id
         )
 
     def handle_value_updated(self, event: Event) -> None:
         """Process a node value updated event."""
         evt_val_data: ValueDataType = event.data["args"]
-        value_id = _get_value_id_from_dict(self, evt_val_data)
+        value_id = _get_value_id_str_from_dict(self, evt_val_data)
         value = self.values.get(value_id)
         if value is None:
             value = _init_value(self, evt_val_data)
@@ -805,7 +854,7 @@ class Node(EventBase):
 
     def handle_value_removed(self, event: Event) -> None:
         """Process a node value removed event."""
-        value_id = _get_value_id_from_dict(self, event.data["args"])
+        value_id = _get_value_id_str_from_dict(self, event.data["args"])
         event.data["value"] = self.values.pop(value_id)
         self.data["values"].pop(self.value_data_idx(value_id))
 
@@ -814,7 +863,7 @@ class Node(EventBase):
         # if value is found, use value data as base and update what is provided
         # in the event, otherwise use the event data
         event_data = event.data["args"]
-        if value := self.values.get(_get_value_id_from_dict(self, event_data)):
+        if value := self.values.get(_get_value_id_str_from_dict(self, event_data)):
             value_notification = ValueNotification(
                 self, cast(ValueDataType, dict(value.data))
             )
